diff -U 3 -H -d -r -N -- openxcom/src/Engine/Options.cpp openxcom/src/Engine/Options.cpp
--- openxcom/src/Engine/Options.cpp	2019-08-22 13:49:17.438299475 +0200
+++ openxcom/src/Engine/Options.cpp	2019-08-22 12:51:56.000000000 +0200
@@ -289,6 +289,9 @@
 	_info.push_back(OptionInfo("FPSInactive", &FPSInactive, 30, "STR_FPS_INACTIVE_LIMIT", "STR_GENERAL"));
 #endif
 
+	_info.push_back(OptionInfo("debugBlast", &debugBlast, 320));
+	_info.push_back(OptionInfo("debugBlastStep", &debugBlastStep, 16));
+
 }
 
 // we can get fancier with these detection routines, but for now just look for
diff -U 3 -H -d -r -N -- openxcom/src/Engine/Options.inc.h openxcom/src/Engine/Options.inc.h
--- openxcom/src/Engine/Options.inc.h	2019-08-22 13:49:17.438299475 +0200
+++ openxcom/src/Engine/Options.inc.h	2019-08-22 12:05:58.000000000 +0200
@@ -46,3 +46,5 @@
 OPT std::string newOpenGLShader;
 OPT std::vector< std::pair<std::string, bool> > mods; // ordered list of available mods (lowest priority to highest) and whether they are active
 OPT SoundFormat currentSound;
+
+OPT int debugBlast, debugBlastStep;
diff -U 3 -H -d -r -N -- openxcom/src/Battlescape/BattlescapeState.cpp openxcom/src/Battlescape/BattlescapeState.cpp
--- openxcom/src/Battlescape/BattlescapeState.cpp	2019-08-22 13:49:17.434299475 +0200
+++ openxcom/src/Battlescape/BattlescapeState.cpp	2019-08-22 12:41:10.000000000 +0200
@@ -22,6 +22,7 @@
 #include <SDL_gfxPrimitives.h>
 #include "Map.h"
 #include "Camera.h"
+#include "ExplosionBState.h"
 #include "BattlescapeState.h"
 #include "AbortMissionState.h"
 #include "TileEngine.h"
@@ -1614,6 +1615,51 @@
 					{
 						saveAIMap();
 					}
+					// B - create debug explosion
+					else if (_save->getDebugMode() && action->getDetails()->key.keysym.sym == SDLK_b && (SDL_GetModState() & KMOD_CTRL) != 0)
+					{
+						Position newPos;
+						_map->getSelectorPosition(&newPos);
+						std::ostringstream ss;
+						ss << "Blast(" << newPos.x << ", " << newPos.y << ", " << newPos.z << ", " << Options::debugBlast << ")";
+						debug(ss.str());
+						newPos.x *= 16;
+						newPos.y *= 16;
+						newPos.z *= 24;
+						if (newPos.x >= 0)
+						{
+							_battleGame->statePushNext
+							(
+								new ExplosionBState
+								(
+									_battleGame,
+									newPos,
+									0,
+									0,
+									0,
+									false,
+									false,
+									Options::debugBlast
+								)
+							);
+						}
+					}
+					// NUMPAD + - increase debug explosion power
+					else if (_save->getDebugMode() && action->getDetails()->key.keysym.sym == SDLK_KP_PLUS && (SDL_GetModState() & KMOD_CTRL) != 0)
+					{
+						Options::debugBlast += Options::debugBlastStep;
+						std::ostringstream ss;
+						ss << "Debug blast power is now " << Options::debugBlast;
+						debug(ss.str());
+					}
+					// NUMPAD - - decrease debug explosion power
+					else if (_save->getDebugMode() && action->getDetails()->key.keysym.sym == SDLK_KP_MINUS && (SDL_GetModState() & KMOD_CTRL) != 0)
+					{
+						Options::debugBlast -= Options::debugBlastStep;
+						std::ostringstream ss;
+						ss << "Debug blast power is now " << Options::debugBlast;
+						debug(ss.str());
+					}
 				}
 				// quick save and quick load
 				if (!_game->getSavedGame()->isIronman())
